@@ -2,7 +2,7 @@ package Keyword::DEVELOPMENT;
 
 use 5.012;    # required for pluggable keywords
 use warnings;
-use Keyword::Declare;
+use Keyword::Simple;
 
 =head1 NAME
 
@@ -10,11 +10,11 @@ Keyword::DEVELOPMENT - Have code blocks which don't exist unless you ask for the
 
 =head1 VERSION
 
-Version 0.01
+Version 0.04
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.04';
 
 =head1 SYNOPSIS
 
@@ -44,15 +44,19 @@ This is primarily a development tool for performance-critical code.
 =cut
 
 sub import {
-    keyword DEVELOPMENT( Block $block) {
+    Keyword::Simple::define 'DEVELOPMENT', sub {
+        my ($ref) = @_;
         if ( $ENV{PERL_KEYWORD_DEVELOPMENT} ) {
-            return $block;
+            substr( $$ref, 0, 0 ) = 'if (1)';
         }
         else {
-            return
-"# PERL_KEYWORD_DEVELOPMENT was false, so the development code was removed.";
+            substr( $$ref, 0, 0 ) = 'if (0)';
         }
-    }
+    };
+}
+
+sub unimport {
+    Keyword::Simple::undefine 'DEVELOPMENT';
 }
 
 =head1 EXAMPLE
@@ -118,39 +122,32 @@ Note the handy line directive on line 13 to ensure your line numbers remain
 correct. If you're not familiar with line directives, see
 L<https://perldoc.perl.org/perlsyn.html#Plain-Old-Comments-(Not!)>
 
+=head1 ALTERNATIVES
+
+As SawyerX pointed out, can replicate the functionality of this module in pure
+Perl, if desired:
+
+    use constant PRODUCTION => !!$ENV{PRODUCTION};
+    DEVELOPMENT {expensive_debugging_code()} unless PRODUCTION;
+
+Versus:
+
+    use Keyword::DEVELOPMENT;
+    DEVELOPMENT {expensive_debugging_code()};
+
+The first version works because the line is removed entirely from the source
+code using constant-folding (if C<PRODUCTION> evaluates to false during
+compile time, the entire line will be omitted).
+
+I think C<Keyword::DEVELOPMENT> is less fragile in that you never need to
+remember the C<unless PRODUCTION> statement modifier. However, we do rely on
+the pluggable keyword functionality introduced in 5.012. Be warned!
+
 =head1 AUTHOR
 
 Curtis "Ovid" Poe, C<< <ovid at allaroundtheworld.fr> >>
 
-=head1 BUGS
-
-The C<Keyword::Declare> module on which this code is based struggles with
-postfix dereferencing. Thus, the following sample program fails:
-
-    #!/usr/bin/env perl
-
-    use 5.024;
-    use Keyword::DEVELOPMENT;
-
-    my $aref = [ 1, 2, 3 ];
-    DEVELOPMENT {
-        my @example = map { $_ => $_ } $aref->@*;
-        print join '-' => @example;
-    }
-
-That fails with the following error message:
-
-	Invalid DEVELOPMENT at declare.pl line 8.
-	Expected:
-		DEVELOPMENT  <block>
-	but found:
-		DEVELOPMENT  {
-	Compilation failed at declare.pl line 8.
-
-Switching from postfix to prefix dereferencing makes the error go away:
-C<@$aref> instead of C<< $aref->@* >>.
-
-See also: L<https://rt.cpan.org/Public/Bug/Display.html?id=123817>
+=head1 BUGS AND LIMITATIONS
 
 Please report any bugs or feature requests to C<bug-keyword-assert at
 rt.cpan.org>, or through the web interface at
